from .base_referee import Referee as Referee
from .naive_referee import NaiveReferee as NaiveReferee
from .classify_early_stopping_referee import ClassifyEarlyStoppingReferee as ClassifyEarlyStoppingReferee
